/* FacebookPublishingAuthenticator.c generated by valac 0.40.4, the Vala compiler
 * generated from FacebookPublishingAuthenticator.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include "shotwell-plugin-common.h"
#include <locale.h>
#include <webkit2/webkit2.h>
#include "shotwell-plugin-dev-1.0.h"
#include <glib/gi18n-lib.h>
#include <libsoup/soup.h>
#include <gobject/gvaluecollector.h>


#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE (publishing_authenticator_shotwell_facebook_web_authentication_pane_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingAuthenticatorShotwellFacebookWebAuthenticationPane))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_WEB_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_WEB_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass))

typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPane PublishingAuthenticatorShotwellFacebookWebAuthenticationPane;
typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass;
typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPanePrivate PublishingAuthenticatorShotwellFacebookWebAuthenticationPanePrivate;
enum  {
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_0_PROPERTY,
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_authenticator_shotwell_facebook_web_authentication_pane_properties[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_NUM_PROPERTIES];

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP (publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_IS_LOCALE_LOOKUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_IS_LOCALE_LOOKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass))

typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup;
typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupPrivate PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupPrivate;
#define _publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref0(var) ((var == NULL) ? NULL : (var = (publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneParamSpecLocaleLookup PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneParamSpecLocaleLookup;
enum  {
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOGIN_SUCCEEDED_SIGNAL,
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOGIN_FAILED_SIGNAL,
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_NUM_SIGNALS
};
static guint publishing_authenticator_shotwell_facebook_web_authentication_pane_signals[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_NUM_SIGNALS] = {0};

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK (publishing_authenticator_shotwell_facebook_facebook_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebookClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebookClass))

typedef struct _PublishingAuthenticatorShotwellFacebookFacebook PublishingAuthenticatorShotwellFacebookFacebook;
typedef struct _PublishingAuthenticatorShotwellFacebookFacebookClass PublishingAuthenticatorShotwellFacebookFacebookClass;
typedef struct _PublishingAuthenticatorShotwellFacebookFacebookPrivate PublishingAuthenticatorShotwellFacebookFacebookPrivate;
enum  {
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_0_PROPERTY,
	PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_NUM_PROPERTIES
};
static GParamSpec* publishing_authenticator_shotwell_facebook_facebook_properties[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_NUM_PROPERTIES];
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPane {
	ShotwellPluginsCommonWebAuthenticationPane parent_instance;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPanePrivate * priv;
};

struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass {
	ShotwellPluginsCommonWebAuthenticationPaneClass parent_class;
};

struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupPrivate * priv;
	gchar* prefix;
	gchar* translation;
	gchar* exception_code;
	gchar* exception_translation;
	gchar* exception_code_2;
	gchar* exception_translation_2;
};

struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup *self);
};

struct _PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneParamSpecLocaleLookup {
	GParamSpec parent_instance;
};

struct _PublishingAuthenticatorShotwellFacebookFacebook {
	GObject parent_instance;
	PublishingAuthenticatorShotwellFacebookFacebookPrivate * priv;
};

struct _PublishingAuthenticatorShotwellFacebookFacebookClass {
	GObjectClass parent_class;
};

struct _PublishingAuthenticatorShotwellFacebookFacebookPrivate {
	SpitPublishingPluginHost* host;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* web_auth_pane;
	GHashTable* params;
};


static gpointer publishing_authenticator_shotwell_facebook_web_authentication_pane_parent_class = NULL;
static gboolean publishing_authenticator_shotwell_facebook_web_authentication_pane_cache_dirty;
static gboolean publishing_authenticator_shotwell_facebook_web_authentication_pane_cache_dirty = FALSE;
static PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup** publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table;
static gint publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table_length1;
static PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup** publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table = NULL;
static gint publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table_length1 = 0;
static gint _publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table_size_ = 0;
static gpointer publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_parent_class = NULL;
static gpointer publishing_authenticator_shotwell_facebook_facebook_parent_class = NULL;
static SpitPublishingAuthenticatorIface * publishing_authenticator_shotwell_facebook_facebook_spit_publishing_authenticator_parent_iface = NULL;

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_APPLICATION_ID "1612018629063184"
GType publishing_authenticator_shotwell_facebook_web_authentication_pane_get_type (void) G_GNUC_CONST;
static gpointer publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (gpointer instance);
static void publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref (gpointer instance);
static GParamSpec* publishing_authenticator_shotwell_facebook_web_authentication_pane_param_spec_locale_lookup (const gchar* name,
                                                                                                         const gchar* nick,
                                                                                                         const gchar* blurb,
                                                                                                         GType object_type,
                                                                                                         GParamFlags flags) G_GNUC_UNUSED;
static void publishing_authenticator_shotwell_facebook_web_authentication_pane_value_set_locale_lookup (GValue* value,
                                                                                                 gpointer v_object) G_GNUC_UNUSED;
static void publishing_authenticator_shotwell_facebook_web_authentication_pane_value_take_locale_lookup (GValue* value,
                                                                                                  gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_authenticator_shotwell_facebook_web_authentication_pane_value_get_locale_lookup (const GValue* value) G_GNUC_UNUSED;
static GType publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new (const gchar* prefix,
                                                                                                                                                                const gchar* translation,
                                                                                                                                                                const gchar* exception_code,
                                                                                                                                                                const gchar* exception_translation,
                                                                                                                                                                const gchar* exception_code_2,
                                                                                                                                                                const gchar* exception_translation_2);
static PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_construct (GType object_type,
                                                                                                                                                                      const gchar* prefix,
                                                                                                                                                                      const gchar* translation,
                                                                                                                                                                      const gchar* exception_code,
                                                                                                                                                                      const gchar* exception_translation,
                                                                                                                                                                      const gchar* exception_code_2,
                                                                                                                                                                      const gchar* exception_translation_2);
PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* publishing_authenticator_shotwell_facebook_web_authentication_pane_new (void);
PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* publishing_authenticator_shotwell_facebook_web_authentication_pane_construct (GType object_type);
static gchar* publishing_authenticator_shotwell_facebook_web_authentication_pane_get_login_url (void);
static gchar* publishing_authenticator_shotwell_facebook_web_authentication_pane_get_system_locale_as_facebook_locale (void);
static void publishing_authenticator_shotwell_facebook_web_authentication_pane_real_on_page_load (ShotwellPluginsCommonWebAuthenticationPane* base);
gboolean publishing_authenticator_shotwell_facebook_web_authentication_pane_is_cache_dirty (void);
static void publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_finalize (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * obj);
static void publishing_authenticator_shotwell_facebook_web_authentication_pane_finalize (GObject * obj);
GType publishing_authenticator_shotwell_facebook_facebook_get_type (void) G_GNUC_CONST;
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebookPrivate))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_SERVICE_WELCOME_MESSAGE _ ("You are not currently logged into Facebook.\n" \
"\n" \
"If you don’t yet have a Facebook account, you can create one during th" \
"e login process. During login, Shotwell Connect may ask you for permis" \
"sion to upload photos and publish to your feed. These permissions are " \
"required for Shotwell Connect to function.")
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_RESTART_ERROR_MESSAGE _ ("You have already logged in and out of Facebook during this Shotwell se" \
"ssion.\n" \
"To continue publishing to Facebook, quit and restart Shotwell, then tr" \
"y publishing again.")
PublishingAuthenticatorShotwellFacebookFacebook* publishing_authenticator_shotwell_facebook_facebook_new (SpitPublishingPluginHost* host);
PublishingAuthenticatorShotwellFacebookFacebook* publishing_authenticator_shotwell_facebook_facebook_construct (GType object_type,
                                                                                                                SpitPublishingPluginHost* host);
static void _g_free0_ (gpointer var);
static void _g_variant_unref0_ (gpointer var);
static void publishing_authenticator_shotwell_facebook_facebook_real_authenticate (SpitPublishingAuthenticator* base);
static gboolean publishing_authenticator_shotwell_facebook_facebook_is_persistent_session_valid (PublishingAuthenticatorShotwellFacebookFacebook* self);
static gchar* publishing_authenticator_shotwell_facebook_facebook_get_persistent_access_token (PublishingAuthenticatorShotwellFacebookFacebook* self);
static void publishing_authenticator_shotwell_facebook_facebook_do_show_service_welcome_pane (PublishingAuthenticatorShotwellFacebookFacebook* self);
static gboolean publishing_authenticator_shotwell_facebook_facebook_real_can_logout (SpitPublishingAuthenticator* base);
static GHashTable* publishing_authenticator_shotwell_facebook_facebook_real_get_authentication_parameter (SpitPublishingAuthenticator* base);
void publishing_authenticator_shotwell_facebook_facebook_invalidate_persistent_session (PublishingAuthenticatorShotwellFacebookFacebook* self);
static void publishing_authenticator_shotwell_facebook_facebook_set_persistent_access_token (PublishingAuthenticatorShotwellFacebookFacebook* self,
                                                                                      const gchar* access_token);
static void publishing_authenticator_shotwell_facebook_facebook_real_logout (SpitPublishingAuthenticator* base);
static void publishing_authenticator_shotwell_facebook_facebook_real_refresh (SpitPublishingAuthenticator* base);
static void publishing_authenticator_shotwell_facebook_facebook_on_login_clicked (PublishingAuthenticatorShotwellFacebookFacebook* self);
static void _publishing_authenticator_shotwell_facebook_facebook_on_login_clicked_spit_publishing_login_callback (gpointer self);
static void publishing_authenticator_shotwell_facebook_facebook_do_hosted_web_authentication (PublishingAuthenticatorShotwellFacebookFacebook* self);
static void publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_succeeded (PublishingAuthenticatorShotwellFacebookFacebook* self,
                                                                                           const gchar* success_url);
static void _publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_succeeded_publishing_authenticator_shotwell_facebook_web_authentication_pane_login_succeeded (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _sender,
                                                                                                                                                                               const gchar* success_url,
                                                                                                                                                                               gpointer self);
static void publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_failed (PublishingAuthenticatorShotwellFacebookFacebook* self);
static void _publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_failed_publishing_authenticator_shotwell_facebook_web_authentication_pane_login_failed (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _sender,
                                                                                                                                                                         gpointer self);
static void publishing_authenticator_shotwell_facebook_facebook_do_authenticate_session (PublishingAuthenticatorShotwellFacebookFacebook* self,
                                                                                  const gchar* good_login_uri);
static void publishing_authenticator_shotwell_facebook_facebook_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


PublishingAuthenticatorShotwellFacebookWebAuthenticationPane*
publishing_authenticator_shotwell_facebook_web_authentication_pane_construct (GType object_type)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 20 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_get_login_url ();
#line 20 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = _tmp0_;
#line 20 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane*) g_object_new (object_type, "login-uri", _tmp1_, NULL);
#line 20 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (_tmp1_);
#line 19 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return self;
#line 238 "FacebookPublishingAuthenticator.c"
}


PublishingAuthenticatorShotwellFacebookWebAuthenticationPane*
publishing_authenticator_shotwell_facebook_web_authentication_pane_new (void)
{
#line 19 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return publishing_authenticator_shotwell_facebook_web_authentication_pane_construct (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE);
#line 247 "FacebookPublishingAuthenticator.c"
}


static gpointer
_publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref0 (gpointer self)
{
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return self ? publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (self) : NULL;
#line 256 "FacebookPublishingAuthenticator.c"
}


static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 276 "FacebookPublishingAuthenticator.c"
}


static gchar*
publishing_authenticator_shotwell_facebook_web_authentication_pane_get_system_locale_as_facebook_locale (void)
{
	gchar* result = NULL;
	const gchar* raw_system_locale = NULL;
	const gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
	gchar* system_locale = NULL;
	const gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup** _tmp12_;
	gint _tmp12__length1;
	gchar* _tmp40_;
#line 93 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = setlocale (LC_ALL, "");
#line 93 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	raw_system_locale = _tmp0_;
#line 94 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = raw_system_locale;
#line 94 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp2_ == NULL) {
#line 94 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp1_ = TRUE;
#line 310 "FacebookPublishingAuthenticator.c"
	} else {
		const gchar* _tmp3_;
#line 94 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp3_ = raw_system_locale;
#line 94 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp1_ = g_strcmp0 (_tmp3_, "") == 0;
#line 317 "FacebookPublishingAuthenticator.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp1_) {
#line 321 "FacebookPublishingAuthenticator.c"
		gchar* _tmp4_;
#line 95 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp4_ = g_strdup ("www");
#line 95 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		result = _tmp4_;
#line 95 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		return result;
#line 329 "FacebookPublishingAuthenticator.c"
	}
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp5_ = raw_system_locale;
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ".", 0);
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp8_ = _tmp7_;
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp8__length1 = _vala_array_length (_tmp6_);
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp9_ = _tmp8_[0];
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp10_ = g_strdup (_tmp9_);
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp11_ = _tmp10_;
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp8_ = (_vala_array_free (_tmp8_, _tmp8__length1, (GDestroyNotify) g_free), NULL);
#line 97 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	system_locale = _tmp11_;
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp12_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table;
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp12__length1 = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table_length1;
#line 353 "FacebookPublishingAuthenticator.c"
	{
		PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup** locale_lookup_collection = NULL;
		gint locale_lookup_collection_length1 = 0;
		gint _locale_lookup_collection_size_ = 0;
		gint locale_lookup_it = 0;
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		locale_lookup_collection = _tmp12_;
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		locale_lookup_collection_length1 = _tmp12__length1;
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		for (locale_lookup_it = 0; locale_lookup_it < _tmp12__length1; locale_lookup_it = locale_lookup_it + 1) {
#line 365 "FacebookPublishingAuthenticator.c"
			PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp13_;
			PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* locale_lookup = NULL;
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
			_tmp13_ = _publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref0 (locale_lookup_collection[locale_lookup_it]);
#line 99 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
			locale_lookup = _tmp13_;
#line 372 "FacebookPublishingAuthenticator.c"
			{
				const gchar* _tmp14_;
				PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp15_;
				const gchar* _tmp16_;
				PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp17_;
				const gchar* _tmp18_;
				PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp27_;
				const gchar* _tmp28_;
				PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp37_;
				const gchar* _tmp38_;
				gchar* _tmp39_;
#line 100 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp14_ = system_locale;
#line 100 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp15_ = locale_lookup;
#line 100 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp16_ = _tmp15_->prefix;
#line 100 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				if (!g_str_has_prefix (_tmp14_, _tmp16_)) {
#line 101 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 101 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					continue;
#line 396 "FacebookPublishingAuthenticator.c"
				}
#line 103 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp17_ = locale_lookup;
#line 103 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp18_ = _tmp17_->exception_code;
#line 103 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				if (_tmp18_ != NULL) {
#line 404 "FacebookPublishingAuthenticator.c"
					PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp19_;
					const gchar* _tmp20_;
					const gchar* _tmp21_;
					PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp22_;
					const gchar* _tmp23_;
#line 104 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp19_ = locale_lookup;
#line 104 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp20_ = _tmp19_->exception_translation;
#line 104 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_vala_assert (_tmp20_ != NULL, "locale_lookup.exception_translation != null");
#line 106 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp21_ = system_locale;
#line 106 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp22_ = locale_lookup;
#line 106 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp23_ = _tmp22_->exception_code;
#line 106 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					if (string_contains (_tmp21_, _tmp23_)) {
#line 424 "FacebookPublishingAuthenticator.c"
						PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp24_;
						const gchar* _tmp25_;
						gchar* _tmp26_;
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_tmp24_ = locale_lookup;
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_tmp25_ = _tmp24_->exception_translation;
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_tmp26_ = g_strdup (_tmp25_);
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						result = _tmp26_;
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_g_free0 (system_locale);
#line 107 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						return result;
#line 442 "FacebookPublishingAuthenticator.c"
					}
				}
#line 110 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp27_ = locale_lookup;
#line 110 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp28_ = _tmp27_->exception_code_2;
#line 110 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				if (_tmp28_ != NULL) {
#line 451 "FacebookPublishingAuthenticator.c"
					PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp29_;
					const gchar* _tmp30_;
					const gchar* _tmp31_;
					PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp32_;
					const gchar* _tmp33_;
#line 111 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp29_ = locale_lookup;
#line 111 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp30_ = _tmp29_->exception_translation_2;
#line 111 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_vala_assert (_tmp30_ != NULL, "locale_lookup.exception_translation_2 != null");
#line 113 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp31_ = system_locale;
#line 113 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp32_ = locale_lookup;
#line 113 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					_tmp33_ = _tmp32_->exception_code_2;
#line 113 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
					if (string_contains (_tmp31_, _tmp33_)) {
#line 471 "FacebookPublishingAuthenticator.c"
						PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp34_;
						const gchar* _tmp35_;
						gchar* _tmp36_;
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_tmp34_ = locale_lookup;
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_tmp35_ = _tmp34_->exception_translation_2;
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_tmp36_ = g_strdup (_tmp35_);
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						result = _tmp36_;
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						_g_free0 (system_locale);
#line 114 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
						return result;
#line 489 "FacebookPublishingAuthenticator.c"
					}
				}
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp37_ = locale_lookup;
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp38_ = _tmp37_->translation;
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_tmp39_ = g_strdup (_tmp38_);
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				result = _tmp39_;
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				_g_free0 (system_locale);
#line 117 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
				return result;
#line 506 "FacebookPublishingAuthenticator.c"
			}
		}
	}
#line 121 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp40_ = g_strdup ("www");
#line 121 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = _tmp40_;
#line 121 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (system_locale);
#line 121 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 518 "FacebookPublishingAuthenticator.c"
}


static gchar*
publishing_authenticator_shotwell_facebook_web_authentication_pane_get_login_url (void)
{
	gchar* result = NULL;
	gchar* facebook_locale = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 125 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_get_system_locale_as_facebook_locale ();
#line 125 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	facebook_locale = _tmp0_;
#line 127 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = g_strdup_printf ("https://%s.facebook.com/dialog/oauth?client_id=%s&redirect_uri=https:/" \
"/www.facebook.com/connect/login_success.html&display=popup&scope=publi" \
"sh_actions,user_photos,user_videos&response_type=token", facebook_locale, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_APPLICATION_ID);
#line 127 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = _tmp1_;
#line 127 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (facebook_locale);
#line 127 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 541 "FacebookPublishingAuthenticator.c"
}


static gint
string_index_of_char (const gchar* self,
                      gunichar c,
                      gint start_index)
{
	gint result = 0;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1045 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 1046 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_utf8_strchr (((gchar*) self) + start_index, (gssize) -1, c);
#line 1046 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1048 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1048 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_ != NULL) {
#line 564 "FacebookPublishingAuthenticator.c"
		gchar* _tmp2_;
#line 1049 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = _result_;
#line 1049 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = (gint) (_tmp2_ - ((gchar*) self));
#line 1049 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 572 "FacebookPublishingAuthenticator.c"
	} else {
#line 1051 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = -1;
#line 1051 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 578 "FacebookPublishingAuthenticator.c"
	}
}


static gchar*
string_slice (const gchar* self,
              glong start,
              glong end)
{
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_;
	gint _tmp1_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gchar* _tmp8_;
#line 1369 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1370 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1370 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1370 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1371 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (start < ((glong) 0)) {
#line 605 "FacebookPublishingAuthenticator.c"
		glong _tmp2_;
#line 1372 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = string_length;
#line 1372 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		start = _tmp2_ + start;
#line 611 "FacebookPublishingAuthenticator.c"
	}
#line 1374 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (end < ((glong) 0)) {
#line 615 "FacebookPublishingAuthenticator.c"
		glong _tmp3_;
#line 1375 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1375 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		end = _tmp3_ + end;
#line 621 "FacebookPublishingAuthenticator.c"
	}
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (start >= ((glong) 0)) {
#line 625 "FacebookPublishingAuthenticator.c"
		glong _tmp5_;
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = string_length;
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = start <= _tmp5_;
#line 631 "FacebookPublishingAuthenticator.c"
	} else {
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = FALSE;
#line 635 "FacebookPublishingAuthenticator.c"
	}
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp4_, NULL);
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (end >= ((glong) 0)) {
#line 641 "FacebookPublishingAuthenticator.c"
		glong _tmp7_;
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = string_length;
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = end <= _tmp7_;
#line 647 "FacebookPublishingAuthenticator.c"
	} else {
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = FALSE;
#line 651 "FacebookPublishingAuthenticator.c"
	}
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp6_, NULL);
#line 1379 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (start <= end, NULL);
#line 1380 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp8_ = g_strndup (((gchar*) self) + start, (gsize) (end - start));
#line 1380 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp8_;
#line 1380 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 663 "FacebookPublishingAuthenticator.c"
}


static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 686 "FacebookPublishingAuthenticator.c"
	} else {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) old)) == '\0';
#line 690 "FacebookPublishingAuthenticator.c"
	}
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 696 "FacebookPublishingAuthenticator.c"
	} else {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
#line 700 "FacebookPublishingAuthenticator.c"
	}
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 704 "FacebookPublishingAuthenticator.c"
		gchar* _tmp2_;
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = g_strdup (self);
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp2_;
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 712 "FacebookPublishingAuthenticator.c"
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_escape_string (old, -1);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = _tmp5_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_free0 (_tmp4_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		regex = _tmp6_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 740 "FacebookPublishingAuthenticator.c"
				goto __catch0_g_regex_error;
			}
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return NULL;
#line 749 "FacebookPublishingAuthenticator.c"
		}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp8_ = regex;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp9_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 763 "FacebookPublishingAuthenticator.c"
				goto __catch0_g_regex_error;
			}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return NULL;
#line 774 "FacebookPublishingAuthenticator.c"
		}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp7_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = NULL;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp10_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_free0 (_tmp7_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 788 "FacebookPublishingAuthenticator.c"
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		GError* e = NULL;
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1429 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 802 "FacebookPublishingAuthenticator.c"
	}
	__finally0:
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return NULL;
#line 813 "FacebookPublishingAuthenticator.c"
	}
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_real_on_page_load (ShotwellPluginsCommonWebAuthenticationPane* base)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane * self;
	gchar* loaded_url = NULL;
	WebKitWebView* _tmp0_;
	WebKitWebView* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp20_;
	const gchar* _tmp25_;
#line 130 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingAuthenticatorShotwellFacebookWebAuthenticationPane);
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = shotwell_plugins_common_web_authentication_pane_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_WEB_AUTHENTICATION_PANE, ShotwellPluginsCommonWebAuthenticationPane));
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = _tmp0_;
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = webkit_web_view_get_uri (_tmp1_);
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp3_ = _tmp2_;
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp5_ = _tmp4_;
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_object_unref0 (_tmp1_);
#line 131 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	loaded_url = _tmp5_;
#line 132 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp6_ = loaded_url;
#line 132 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp7_ = g_strconcat ("loaded url: ", _tmp6_, NULL);
#line 132 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp8_ = _tmp7_;
#line 132 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:132: %s", _tmp8_);
#line 132 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (_tmp8_);
#line 135 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp9_ = loaded_url;
#line 135 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (string_contains (_tmp9_, "?")) {
#line 867 "FacebookPublishingAuthenticator.c"
		gint index = 0;
		const gchar* _tmp10_;
		gchar* params = NULL;
		const gchar* _tmp11_;
		gint _tmp12_;
		const gchar* _tmp13_;
		gint _tmp14_;
		gint _tmp15_;
		gchar* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
		gchar* _tmp19_;
#line 136 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp10_ = loaded_url;
#line 136 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		index = string_index_of_char (_tmp10_, (gunichar) '?', 0);
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp11_ = loaded_url;
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp12_ = index;
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp13_ = loaded_url;
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp14_ = strlen (_tmp13_);
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp15_ = _tmp14_;
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp16_ = string_slice (_tmp11_, (glong) _tmp12_, (glong) _tmp15_);
#line 137 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		params = _tmp16_;
#line 138 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp17_ = loaded_url;
#line 138 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp18_ = params;
#line 138 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp19_ = string_replace (_tmp17_, _tmp18_, "");
#line 138 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (loaded_url);
#line 138 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		loaded_url = _tmp19_;
#line 135 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (params);
#line 910 "FacebookPublishingAuthenticator.c"
	}
#line 142 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp20_ = loaded_url;
#line 142 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (string_contains (_tmp20_, "login_success")) {
#line 916 "FacebookPublishingAuthenticator.c"
		WebKitWebView* _tmp21_;
		WebKitWebView* _tmp22_;
		const gchar* _tmp23_;
		const gchar* _tmp24_;
#line 143 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		publishing_authenticator_shotwell_facebook_web_authentication_pane_cache_dirty = TRUE;
#line 144 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp21_ = shotwell_plugins_common_web_authentication_pane_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_WEB_AUTHENTICATION_PANE, ShotwellPluginsCommonWebAuthenticationPane));
#line 144 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp22_ = _tmp21_;
#line 144 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp23_ = webkit_web_view_get_uri (_tmp22_);
#line 144 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp24_ = _tmp23_;
#line 144 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_signal_emit (self, publishing_authenticator_shotwell_facebook_web_authentication_pane_signals[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOGIN_SUCCEEDED_SIGNAL], 0, _tmp24_);
#line 144 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_object_unref0 (_tmp22_);
#line 145 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (loaded_url);
#line 145 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		return;
#line 939 "FacebookPublishingAuthenticator.c"
	}
#line 149 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp25_ = loaded_url;
#line 149 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (string_contains (_tmp25_, "login_failure")) {
#line 150 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_signal_emit (self, publishing_authenticator_shotwell_facebook_web_authentication_pane_signals[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOGIN_FAILED_SIGNAL], 0);
#line 151 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (loaded_url);
#line 151 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		return;
#line 951 "FacebookPublishingAuthenticator.c"
	}
#line 130 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (loaded_url);
#line 955 "FacebookPublishingAuthenticator.c"
}


gboolean
publishing_authenticator_shotwell_facebook_web_authentication_pane_is_cache_dirty (void)
{
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 156 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_cache_dirty;
#line 156 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = _tmp0_;
#line 156 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 970 "FacebookPublishingAuthenticator.c"
}


static PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup*
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_construct (GType object_type,
                                                                                            const gchar* prefix,
                                                                                            const gchar* translation,
                                                                                            const gchar* exception_code,
                                                                                            const gchar* exception_translation,
                                                                                            const gchar* exception_code_2,
                                                                                            const gchar* exception_translation_2)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (prefix != NULL, NULL);
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (translation != NULL, NULL);
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup*) g_type_create_instance (object_type);
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = g_strdup (prefix);
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->prefix);
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->prefix = _tmp0_;
#line 35 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = g_strdup (translation);
#line 35 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->translation);
#line 35 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->translation = _tmp1_;
#line 36 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = g_strdup (exception_code);
#line 36 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_code);
#line 36 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->exception_code = _tmp2_;
#line 37 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp3_ = g_strdup (exception_translation);
#line 37 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_translation);
#line 37 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->exception_translation = _tmp3_;
#line 38 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp4_ = g_strdup (exception_code_2);
#line 38 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_code_2);
#line 38 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->exception_code_2 = _tmp4_;
#line 39 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp5_ = g_strdup (exception_translation_2);
#line 39 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_translation_2);
#line 39 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->exception_translation_2 = _tmp5_;
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return self;
#line 1034 "FacebookPublishingAuthenticator.c"
}


static PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup*
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new (const gchar* prefix,
                                                                                      const gchar* translation,
                                                                                      const gchar* exception_code,
                                                                                      const gchar* exception_translation,
                                                                                      const gchar* exception_code_2,
                                                                                      const gchar* exception_translation_2)
{
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_construct (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, prefix, translation, exception_code, exception_translation, exception_code_2, exception_translation_2);
#line 1048 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_init (GValue* value)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	value->data[0].v_pointer = NULL;
#line 1057 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_free_value (GValue* value)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (value->data[0].v_pointer) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref (value->data[0].v_pointer);
#line 1068 "FacebookPublishingAuthenticator.c"
	}
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_copy_value (const GValue* src_value,
                                                                                                   GValue* dest_value)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (src_value->data[0].v_pointer) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		dest_value->data[0].v_pointer = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (src_value->data[0].v_pointer);
#line 1081 "FacebookPublishingAuthenticator.c"
	} else {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1085 "FacebookPublishingAuthenticator.c"
	}
}


static gpointer
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_peek_pointer (const GValue* value)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return value->data[0].v_pointer;
#line 1095 "FacebookPublishingAuthenticator.c"
}


static gchar*
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_collect_value (GValue* value,
                                                                                                      guint n_collect_values,
                                                                                                      GTypeCValue* collect_values,
                                                                                                      guint collect_flags)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (collect_values[0].v_pointer) {
#line 1107 "FacebookPublishingAuthenticator.c"
		PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * object;
		object = collect_values[0].v_pointer;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1114 "FacebookPublishingAuthenticator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1118 "FacebookPublishingAuthenticator.c"
		}
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		value->data[0].v_pointer = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (object);
#line 1122 "FacebookPublishingAuthenticator.c"
	} else {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		value->data[0].v_pointer = NULL;
#line 1126 "FacebookPublishingAuthenticator.c"
	}
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return NULL;
#line 1130 "FacebookPublishingAuthenticator.c"
}


static gchar*
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_lcopy_value (const GValue* value,
                                                                                                    guint n_collect_values,
                                                                                                    GTypeCValue* collect_values,
                                                                                                    guint collect_flags)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup ** object_p;
	object_p = collect_values[0].v_pointer;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (!object_p) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1146 "FacebookPublishingAuthenticator.c"
	}
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (!value->data[0].v_pointer) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		*object_p = NULL;
#line 1152 "FacebookPublishingAuthenticator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		*object_p = value->data[0].v_pointer;
#line 1156 "FacebookPublishingAuthenticator.c"
	} else {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		*object_p = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (value->data[0].v_pointer);
#line 1160 "FacebookPublishingAuthenticator.c"
	}
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return NULL;
#line 1164 "FacebookPublishingAuthenticator.c"
}


static GParamSpec*
publishing_authenticator_shotwell_facebook_web_authentication_pane_param_spec_locale_lookup (const gchar* name,
                                                                                             const gchar* nick,
                                                                                             const gchar* blurb,
                                                                                             GType object_type,
                                                                                             GParamFlags flags)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneParamSpecLocaleLookup* spec;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP), NULL);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return G_PARAM_SPEC (spec);
#line 1184 "FacebookPublishingAuthenticator.c"
}


static gpointer
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_get_locale_lookup (const GValue* value)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP), NULL);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return value->data[0].v_pointer;
#line 1195 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_set_locale_lookup (GValue* value,
                                                                                            gpointer v_object)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * old;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	old = value->data[0].v_pointer;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (v_object) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		value->data[0].v_pointer = v_object;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (value->data[0].v_pointer);
#line 1218 "FacebookPublishingAuthenticator.c"
	} else {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		value->data[0].v_pointer = NULL;
#line 1222 "FacebookPublishingAuthenticator.c"
	}
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (old) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref (old);
#line 1228 "FacebookPublishingAuthenticator.c"
	}
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_value_take_locale_lookup (GValue* value,
                                                                                             gpointer v_object)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * old;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	old = value->data[0].v_pointer;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (v_object) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		value->data[0].v_pointer = v_object;
#line 1250 "FacebookPublishingAuthenticator.c"
	} else {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		value->data[0].v_pointer = NULL;
#line 1254 "FacebookPublishingAuthenticator.c"
	}
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (old) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref (old);
#line 1260 "FacebookPublishingAuthenticator.c"
	}
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_class_init (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass * klass)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_parent_class = g_type_class_peek_parent (klass);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	((PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass *) klass)->finalize = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_finalize;
#line 1272 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_instance_init (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * self)
{
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->ref_count = 1;
#line 1281 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_finalize (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * obj)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * self;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_signal_handlers_destroy (self);
#line 24 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->prefix);
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->translation);
#line 26 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_code);
#line 27 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_translation);
#line 28 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_code_2);
#line 29 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (self->exception_translation_2);
#line 1305 "FacebookPublishingAuthenticator.c"
}


static GType
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_get_type (void)
{
	static volatile gsize publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_init, publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_free_value, publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_copy_value, publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_peek_pointer, "p", publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_collect_value, "p", publishing_authenticator_shotwell_facebook_web_authentication_pane_value_locale_lookup_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup), 0, (GInstanceInitFunc) publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id;
		publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id__volatile, publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id);
	}
	return publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_type_id__volatile;
}


static gpointer
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_ref (gpointer instance)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * self;
	self = instance;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return instance;
#line 1334 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_unref (gpointer instance)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup * self;
	self = instance;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_GET_CLASS (self)->finalize (self);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1349 "FacebookPublishingAuthenticator.c"
	}
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_class_init (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass * klass)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp0_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp1_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp2_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp3_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp4_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp5_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp6_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp7_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp8_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp9_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp10_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp11_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp12_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp13_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp14_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp15_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp16_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp17_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp18_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp19_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp20_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp21_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp22_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp23_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp24_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp25_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp26_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp27_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp28_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp29_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp30_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp31_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp32_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp33_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp34_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp35_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp36_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp37_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp38_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp39_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp40_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp41_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp42_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp43_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup* _tmp44_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup** _tmp45_;
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_web_authentication_pane_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	((ShotwellPluginsCommonWebAuthenticationPaneClass *) klass)->on_page_load = (void (*) (ShotwellPluginsCommonWebAuthenticationPane *)) publishing_authenticator_shotwell_facebook_web_authentication_pane_real_on_page_load;
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_authenticator_shotwell_facebook_web_authentication_pane_finalize;
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_web_authentication_pane_signals[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOGIN_SUCCEEDED_SIGNAL] = g_signal_new ("login-succeeded", PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_web_authentication_pane_signals[PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_WEB_AUTHENTICATION_PANE_LOGIN_FAILED_SIGNAL] = g_signal_new ("login-failed", PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("es", "es-la", "ES", "es-es", NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("en", "en-gb", "US", "en-us", NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("fr", "fr-fr", "CA", "fr-ca", NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp3_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("pt", "pt-br", "PT", "pt-pt", NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp4_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("zh", "zh-cn", "HK", "zh-hk", "TW", "zh-tw");
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp5_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("af", "af-za", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp6_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ar", "ar-ar", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp7_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("nb", "nb-no", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp8_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("no", "nb-no", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp9_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("id", "id-id", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp10_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ms", "ms-my", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp11_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ca", "ca-es", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp12_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("cs", "cs-cz", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp13_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("cy", "cy-gb", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp14_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("da", "da-dk", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp15_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("de", "de-de", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp16_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("tl", "tl-ph", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp17_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ko", "ko-kr", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp18_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("hr", "hr-hr", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp19_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("it", "it-it", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp20_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("lt", "lt-lt", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp21_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("hu", "hu-hu", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp22_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("nl", "nl-nl", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp23_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ja", "ja-jp", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp24_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("nb", "nb-no", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp25_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("no", "nb-no", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp26_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("pl", "pl-pl", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp27_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ro", "ro-ro", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp28_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ru", "ru-ru", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp29_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("sk", "sk-sk", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp30_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("sl", "sl-si", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp31_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("sv", "sv-se", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp32_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("th", "th-th", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp33_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("vi", "vi-vn", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp34_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("tr", "tr-tr", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp35_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("el", "el-gr", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp36_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("bg", "bg-bg", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp37_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("sr", "sr-rs", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp38_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("he", "he-il", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp39_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("hi", "hi-in", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp40_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("bn", "bn-in", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp41_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("pa", "pa-in", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp42_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ta", "ta-in", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp43_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("te", "te-in", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp44_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_new ("ml", "ml-in", NULL, NULL, NULL, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_ = g_new0 (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneLocaleLookup*, 45 + 1);
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[0] = _tmp0_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[1] = _tmp1_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[2] = _tmp2_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[3] = _tmp3_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[4] = _tmp4_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[5] = _tmp5_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[6] = _tmp6_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[7] = _tmp7_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[8] = _tmp8_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[9] = _tmp9_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[10] = _tmp10_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[11] = _tmp11_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[12] = _tmp12_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[13] = _tmp13_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[14] = _tmp14_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[15] = _tmp15_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[16] = _tmp16_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[17] = _tmp17_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[18] = _tmp18_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[19] = _tmp19_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[20] = _tmp20_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[21] = _tmp21_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[22] = _tmp22_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[23] = _tmp23_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[24] = _tmp24_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[25] = _tmp25_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[26] = _tmp26_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[27] = _tmp27_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[28] = _tmp28_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[29] = _tmp29_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[30] = _tmp30_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[31] = _tmp31_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[32] = _tmp32_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[33] = _tmp33_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[34] = _tmp34_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[35] = _tmp35_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[36] = _tmp36_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[37] = _tmp37_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[38] = _tmp38_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[39] = _tmp39_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[40] = _tmp40_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[41] = _tmp41_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[42] = _tmp42_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[43] = _tmp43_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp45_[44] = _tmp44_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table = _tmp45_;
#line 44 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_web_authentication_pane_locale_lookup_table_length1 = 45;
#line 1599 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_instance_init (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane * self)
{
}


static void
publishing_authenticator_shotwell_facebook_web_authentication_pane_finalize (GObject * obj)
{
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane * self;
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingAuthenticatorShotwellFacebookWebAuthenticationPane);
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	G_OBJECT_CLASS (publishing_authenticator_shotwell_facebook_web_authentication_pane_parent_class)->finalize (obj);
#line 1617 "FacebookPublishingAuthenticator.c"
}


GType
publishing_authenticator_shotwell_facebook_web_authentication_pane_get_type (void)
{
	static volatile gsize publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingAuthenticatorShotwellFacebookWebAuthenticationPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_authenticator_shotwell_facebook_web_authentication_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane), 0, (GInstanceInitFunc) publishing_authenticator_shotwell_facebook_web_authentication_pane_instance_init, NULL };
		GType publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id;
		publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id = g_type_register_static (SHOTWELL_PLUGINS_COMMON_TYPE_WEB_AUTHENTICATION_PANE, "PublishingAuthenticatorShotwellFacebookWebAuthenticationPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id__volatile, publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id);
	}
	return publishing_authenticator_shotwell_facebook_web_authentication_pane_type_id__volatile;
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 172 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return self ? g_object_ref (self) : NULL;
#line 1640 "FacebookPublishingAuthenticator.c"
}


static void
_g_free0_ (gpointer var)
{
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	var = (g_free (var), NULL);
#line 1649 "FacebookPublishingAuthenticator.c"
}


static void
_g_variant_unref0_ (gpointer var)
{
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	(var == NULL) ? NULL : (var = (g_variant_unref (var), NULL));
#line 1658 "FacebookPublishingAuthenticator.c"
}


PublishingAuthenticatorShotwellFacebookFacebook*
publishing_authenticator_shotwell_facebook_facebook_construct (GType object_type,
                                                               SpitPublishingPluginHost* host)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self = NULL;
	SpitPublishingPluginHost* _tmp0_;
	GHashFunc _tmp1_;
	GEqualFunc _tmp2_;
	GHashTable* _tmp3_;
#line 171 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 171 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = (PublishingAuthenticatorShotwellFacebookFacebook*) g_object_new (object_type, NULL);
#line 172 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = _g_object_ref0 (host);
#line 172 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_object_unref0 (self->priv->host);
#line 172 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->priv->host = _tmp0_;
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = g_str_hash;
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = g_str_equal;
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp3_ = g_hash_table_new_full (_tmp1_, _tmp2_, _g_free0_, _g_variant_unref0_);
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_hash_table_unref0 (self->priv->params);
#line 173 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->priv->params = _tmp3_;
#line 171 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return self;
#line 1693 "FacebookPublishingAuthenticator.c"
}


PublishingAuthenticatorShotwellFacebookFacebook*
publishing_authenticator_shotwell_facebook_facebook_new (SpitPublishingPluginHost* host)
{
#line 171 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return publishing_authenticator_shotwell_facebook_facebook_construct (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, host);
#line 1702 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_real_authenticate (SpitPublishingAuthenticator* base)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self;
#line 176 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook);
#line 180 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (publishing_authenticator_shotwell_facebook_facebook_is_persistent_session_valid (self)) {
#line 1714 "FacebookPublishingAuthenticator.c"
		gchar* access_token = NULL;
		gchar* _tmp0_;
		GHashTable* _tmp1_;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		GVariant* _tmp4_;
#line 181 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp0_ = publishing_authenticator_shotwell_facebook_facebook_get_persistent_access_token (self);
#line 181 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		access_token = _tmp0_;
#line 182 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp1_ = self->priv->params;
#line 182 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp2_ = g_strdup ("AccessToken");
#line 182 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp3_ = access_token;
#line 182 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp4_ = g_variant_new_string (_tmp3_);
#line 182 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_variant_ref_sink (_tmp4_);
#line 182 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_hash_table_insert (_tmp1_, _tmp2_, _tmp4_);
#line 183 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator), "authenticated");
#line 184 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (access_token);
#line 184 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		return;
#line 1743 "FacebookPublishingAuthenticator.c"
	}
#line 188 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (publishing_authenticator_shotwell_facebook_web_authentication_pane_is_cache_dirty ()) {
#line 1747 "FacebookPublishingAuthenticator.c"
		SpitPublishingPluginHost* _tmp5_;
		SpitPublishingPluginHost* _tmp6_;
#line 189 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp5_ = self->priv->host;
#line 189 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		spit_publishing_plugin_host_set_service_locked (_tmp5_, FALSE);
#line 190 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp6_ = self->priv->host;
#line 190 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		spit_publishing_plugin_host_install_static_message_pane (_tmp6_, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_RESTART_ERROR_MESSAGE, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 1758 "FacebookPublishingAuthenticator.c"
	} else {
#line 193 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		publishing_authenticator_shotwell_facebook_facebook_do_show_service_welcome_pane (self);
#line 1762 "FacebookPublishingAuthenticator.c"
	}
}


static gboolean
publishing_authenticator_shotwell_facebook_facebook_real_can_logout (SpitPublishingAuthenticator* base)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self;
	gboolean result = FALSE;
#line 197 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook);
#line 198 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = TRUE;
#line 198 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 1778 "FacebookPublishingAuthenticator.c"
}


static gpointer
_g_hash_table_ref0 (gpointer self)
{
#line 202 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return self ? g_hash_table_ref (self) : NULL;
#line 1787 "FacebookPublishingAuthenticator.c"
}


static GHashTable*
publishing_authenticator_shotwell_facebook_facebook_real_get_authentication_parameter (SpitPublishingAuthenticator* base)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self;
	GHashTable* result = NULL;
	GHashTable* _tmp0_;
	GHashTable* _tmp1_;
#line 201 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook);
#line 202 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = self->priv->params;
#line 202 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = _g_hash_table_ref0 (_tmp0_);
#line 202 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = _tmp1_;
#line 202 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 1808 "FacebookPublishingAuthenticator.c"
}


void
publishing_authenticator_shotwell_facebook_facebook_invalidate_persistent_session (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
#line 205 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 206 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:206: invalidating saved Facebook " \
"session.");
#line 207 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_set_persistent_access_token (self, "");
#line 1821 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_real_logout (SpitPublishingAuthenticator* base)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self;
#line 210 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook);
#line 211 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_invalidate_persistent_session (self);
#line 1833 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_real_refresh (SpitPublishingAuthenticator* base)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self;
#line 214 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook);
#line 1843 "FacebookPublishingAuthenticator.c"
}


static gboolean
publishing_authenticator_shotwell_facebook_facebook_is_persistent_session_valid (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
	gboolean result = FALSE;
	gchar* token = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
#line 219 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self), FALSE);
#line 220 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = publishing_authenticator_shotwell_facebook_facebook_get_persistent_access_token (self);
#line 220 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	token = _tmp0_;
#line 222 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = token;
#line 222 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp1_ != NULL) {
#line 1865 "FacebookPublishingAuthenticator.c"
		const gchar* _tmp2_;
#line 223 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp2_ = token;
#line 223 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_debug ("FacebookPublishingAuthenticator.vala:223: existing Facebook session fo" \
"und in configuration database (access_token = %s).", _tmp2_);
#line 1871 "FacebookPublishingAuthenticator.c"
	} else {
#line 226 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		g_debug ("FacebookPublishingAuthenticator.vala:226: no existing Facebook session" \
" available.");
#line 1875 "FacebookPublishingAuthenticator.c"
	}
#line 228 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp3_ = token;
#line 228 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = _tmp3_ != NULL;
#line 228 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (token);
#line 228 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 1885 "FacebookPublishingAuthenticator.c"
}


static gchar*
publishing_authenticator_shotwell_facebook_facebook_get_persistent_access_token (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 231 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_val_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self), NULL);
#line 232 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = self->priv->host;
#line 232 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_token", NULL);
#line 232 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	result = _tmp1_;
#line 232 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	return result;
#line 1905 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_set_persistent_access_token (PublishingAuthenticatorShotwellFacebookFacebook* self,
                                                                                 const gchar* access_token)
{
	SpitPublishingPluginHost* _tmp0_;
#line 235 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 235 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (access_token != NULL);
#line 236 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = self->priv->host;
#line 236 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_token", access_token);
#line 1922 "FacebookPublishingAuthenticator.c"
}


static void
_publishing_authenticator_shotwell_facebook_facebook_on_login_clicked_spit_publishing_login_callback (gpointer self)
{
#line 242 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_on_login_clicked ((PublishingAuthenticatorShotwellFacebookFacebook*) self);
#line 1931 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_do_show_service_welcome_pane (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 239 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 240 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:240: ACTION: showing service welc" \
"ome pane.");
#line 242 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = self->priv->host;
#line 242 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	spit_publishing_plugin_host_install_welcome_pane (_tmp0_, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_SERVICE_WELCOME_MESSAGE, _publishing_authenticator_shotwell_facebook_facebook_on_login_clicked_spit_publishing_login_callback, self);
#line 243 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = self->priv->host;
#line 243 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, FALSE);
#line 1952 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_on_login_clicked (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
#line 246 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 247 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:247: EVENT: user clicked 'Login' " \
"on welcome pane.");
#line 249 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_do_hosted_web_authentication (self);
#line 1965 "FacebookPublishingAuthenticator.c"
}


static void
_publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_succeeded_publishing_authenticator_shotwell_facebook_web_authentication_pane_login_succeeded (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _sender,
                                                                                                                                                                          const gchar* success_url,
                                                                                                                                                                          gpointer self)
{
#line 258 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_succeeded ((PublishingAuthenticatorShotwellFacebookFacebook*) self, success_url);
#line 1976 "FacebookPublishingAuthenticator.c"
}


static void
_publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_failed_publishing_authenticator_shotwell_facebook_web_authentication_pane_login_failed (PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _sender,
                                                                                                                                                                    gpointer self)
{
#line 259 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_failed ((PublishingAuthenticatorShotwellFacebookFacebook*) self);
#line 1986 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_do_hosted_web_authentication (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _tmp1_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _tmp2_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _tmp3_;
	SpitPublishingPluginHost* _tmp4_;
	PublishingAuthenticatorShotwellFacebookWebAuthenticationPane* _tmp5_;
#line 252 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 253 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:253: ACTION: doing hosted web aut" \
"hentication.");
#line 255 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = self->priv->host;
#line 255 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 257 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = publishing_authenticator_shotwell_facebook_web_authentication_pane_new ();
#line 257 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_object_unref0 (self->priv->web_auth_pane);
#line 257 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->priv->web_auth_pane = _tmp1_;
#line 258 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = self->priv->web_auth_pane;
#line 258 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_signal_connect_object (_tmp2_, "login-succeeded", (GCallback) _publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_succeeded_publishing_authenticator_shotwell_facebook_web_authentication_pane_login_succeeded, self, 0);
#line 259 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp3_ = self->priv->web_auth_pane;
#line 259 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_signal_connect_object (_tmp3_, "login-failed", (GCallback) _publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_failed_publishing_authenticator_shotwell_facebook_web_authentication_pane_login_failed, self, 0);
#line 261 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp4_ = self->priv->host;
#line 261 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp5_ = self->priv->web_auth_pane;
#line 261 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 2027 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_succeeded (PublishingAuthenticatorShotwellFacebookFacebook* self,
                                                                                      const gchar* success_url)
{
#line 266 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 266 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (success_url != NULL);
#line 267 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:267: EVENT: hosted web login succ" \
"eeded.");
#line 269 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_do_authenticate_session (self, success_url);
#line 2043 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_on_web_auth_pane_login_failed (PublishingAuthenticatorShotwellFacebookFacebook* self)
{
#line 272 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 273 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:273: EVENT: hosted web login fail" \
"ed.");
#line 281 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_do_show_service_welcome_pane (self);
#line 2056 "FacebookPublishingAuthenticator.c"
}


static gint
string_index_of (const gchar* self,
                 const gchar* needle,
                 gint start_index)
{
	gint result = 0;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1025 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 1025 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, 0);
#line 1026 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strstr (((gchar*) self) + start_index, (gchar*) needle);
#line 1026 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1028 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1028 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_ != NULL) {
#line 2081 "FacebookPublishingAuthenticator.c"
		gchar* _tmp2_;
#line 1029 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = _result_;
#line 1029 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = (gint) (_tmp2_ - ((gchar*) self));
#line 1029 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 2089 "FacebookPublishingAuthenticator.c"
	} else {
#line 1031 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = -1;
#line 1031 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 2095 "FacebookPublishingAuthenticator.c"
	}
}


static void
publishing_authenticator_shotwell_facebook_facebook_do_authenticate_session (PublishingAuthenticatorShotwellFacebookFacebook* self,
                                                                             const gchar* good_login_uri)
{
	gchar* decoded_uri = NULL;
	gchar* _tmp0_;
	gchar* access_token = NULL;
	gint index = 0;
	const gchar* _tmp1_;
	gint _tmp2_;
	const gchar* _tmp9_;
	gchar* trailing_params = NULL;
	const gchar* _tmp13_;
	gint _tmp14_;
	const gchar* _tmp21_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	GHashTable* _tmp27_;
	gchar* _tmp28_;
	const gchar* _tmp29_;
	GVariant* _tmp30_;
	const gchar* _tmp31_;
#line 284 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK (self));
#line 284 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_return_if_fail (good_login_uri != NULL);
#line 285 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_debug ("FacebookPublishingAuthenticator.vala:285: ACTION: preparing to extract" \
" session information encoded in uri = '%s'", good_login_uri);
#line 289 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp0_ = soup_uri_decode (good_login_uri);
#line 289 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	decoded_uri = _tmp0_;
#line 292 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	access_token = NULL;
#line 293 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp1_ = decoded_uri;
#line 293 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	index = string_index_of (_tmp1_, "#access_token=", 0);
#line 294 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp2_ = index;
#line 294 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp2_ >= 0) {
#line 2142 "FacebookPublishingAuthenticator.c"
		const gchar* _tmp3_;
		gint _tmp4_;
		const gchar* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
		gchar* _tmp8_;
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp3_ = decoded_uri;
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp4_ = index;
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp5_ = decoded_uri;
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp6_ = strlen (_tmp5_);
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp7_ = _tmp6_;
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp8_ = string_slice (_tmp3_, (glong) _tmp4_, (glong) _tmp7_);
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (access_token);
#line 295 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		access_token = _tmp8_;
#line 2165 "FacebookPublishingAuthenticator.c"
	}
#line 296 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp9_ = access_token;
#line 296 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp9_ == NULL) {
#line 2171 "FacebookPublishingAuthenticator.c"
		SpitPublishingPluginHost* _tmp10_;
		GError* _tmp11_;
		GError* _tmp12_;
#line 297 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp10_ = self->priv->host;
#line 297 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp11_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "Server redirect URL contained no access token");
#line 297 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp12_ = _tmp11_;
#line 297 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		spit_publishing_plugin_host_post_error (_tmp10_, _tmp12_);
#line 297 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_error_free0 (_tmp12_);
#line 299 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (access_token);
#line 299 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (decoded_uri);
#line 299 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		return;
#line 2191 "FacebookPublishingAuthenticator.c"
	}
#line 303 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	trailing_params = NULL;
#line 304 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp13_ = access_token;
#line 304 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	index = string_index_of_char (_tmp13_, (gunichar) '&', 0);
#line 305 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp14_ = index;
#line 305 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp14_ >= 0) {
#line 2203 "FacebookPublishingAuthenticator.c"
		const gchar* _tmp15_;
		gint _tmp16_;
		const gchar* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
		gchar* _tmp20_;
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp15_ = access_token;
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp16_ = index;
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp17_ = access_token;
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp18_ = strlen (_tmp17_);
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp19_ = _tmp18_;
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp20_ = string_slice (_tmp15_, (glong) _tmp16_, (glong) _tmp19_);
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (trailing_params);
#line 306 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		trailing_params = _tmp20_;
#line 2226 "FacebookPublishingAuthenticator.c"
	}
#line 307 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp21_ = trailing_params;
#line 307 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	if (_tmp21_ != NULL) {
#line 2232 "FacebookPublishingAuthenticator.c"
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		gchar* _tmp24_;
#line 308 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp22_ = access_token;
#line 308 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp23_ = trailing_params;
#line 308 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_tmp24_ = string_replace (_tmp22_, _tmp23_, "");
#line 308 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		_g_free0 (access_token);
#line 308 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
		access_token = _tmp24_;
#line 2246 "FacebookPublishingAuthenticator.c"
	}
#line 311 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp25_ = access_token;
#line 311 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp26_ = string_replace (_tmp25_, "#access_token=", "");
#line 311 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (access_token);
#line 311 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	access_token = _tmp26_;
#line 312 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp27_ = self->priv->params;
#line 312 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp28_ = g_strdup ("AccessToken");
#line 312 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp29_ = access_token;
#line 312 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp30_ = g_variant_new_string (_tmp29_);
#line 312 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_variant_ref_sink (_tmp30_);
#line 312 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_hash_table_insert (_tmp27_, _tmp28_, _tmp30_);
#line 313 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_tmp31_ = access_token;
#line 313 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_set_persistent_access_token (self, _tmp31_);
#line 315 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator), "authenticated");
#line 284 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (trailing_params);
#line 284 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (access_token);
#line 284 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_free0 (decoded_uri);
#line 2280 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_class_init (PublishingAuthenticatorShotwellFacebookFacebookClass * klass)
{
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_parent_class = g_type_class_peek_parent (klass);
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	g_type_class_add_private (klass, sizeof (PublishingAuthenticatorShotwellFacebookFacebookPrivate));
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_authenticator_shotwell_facebook_facebook_finalize;
#line 2293 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_spit_publishing_authenticator_interface_init (SpitPublishingAuthenticatorIface * iface)
{
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	publishing_authenticator_shotwell_facebook_facebook_spit_publishing_authenticator_parent_iface = g_type_interface_peek_parent (iface);
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	iface->authenticate = (void (*) (SpitPublishingAuthenticator *)) publishing_authenticator_shotwell_facebook_facebook_real_authenticate;
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	iface->can_logout = (gboolean (*) (SpitPublishingAuthenticator *)) publishing_authenticator_shotwell_facebook_facebook_real_can_logout;
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	iface->get_authentication_parameter = (GHashTable* (*) (SpitPublishingAuthenticator *)) publishing_authenticator_shotwell_facebook_facebook_real_get_authentication_parameter;
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	iface->logout = (void (*) (SpitPublishingAuthenticator *)) publishing_authenticator_shotwell_facebook_facebook_real_logout;
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	iface->refresh = (void (*) (SpitPublishingAuthenticator *)) publishing_authenticator_shotwell_facebook_facebook_real_refresh;
#line 2312 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_instance_init (PublishingAuthenticatorShotwellFacebookFacebook * self)
{
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->priv = PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_GET_PRIVATE (self);
#line 162 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self->priv->web_auth_pane = NULL;
#line 2323 "FacebookPublishingAuthenticator.c"
}


static void
publishing_authenticator_shotwell_facebook_facebook_finalize (GObject * obj)
{
	PublishingAuthenticatorShotwellFacebookFacebook * self;
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook);
#line 161 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_object_unref0 (self->priv->host);
#line 162 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_object_unref0 (self->priv->web_auth_pane);
#line 163 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	_g_hash_table_unref0 (self->priv->params);
#line 160 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/FacebookPublishingAuthenticator.vala"
	G_OBJECT_CLASS (publishing_authenticator_shotwell_facebook_facebook_parent_class)->finalize (obj);
#line 2341 "FacebookPublishingAuthenticator.c"
}


GType
publishing_authenticator_shotwell_facebook_facebook_get_type (void)
{
	static volatile gsize publishing_authenticator_shotwell_facebook_facebook_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_authenticator_shotwell_facebook_facebook_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingAuthenticatorShotwellFacebookFacebookClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_authenticator_shotwell_facebook_facebook_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingAuthenticatorShotwellFacebookFacebook), 0, (GInstanceInitFunc) publishing_authenticator_shotwell_facebook_facebook_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_authenticator_info = { (GInterfaceInitFunc) publishing_authenticator_shotwell_facebook_facebook_spit_publishing_authenticator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_authenticator_shotwell_facebook_facebook_type_id;
		publishing_authenticator_shotwell_facebook_facebook_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingAuthenticatorShotwellFacebookFacebook", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_authenticator_shotwell_facebook_facebook_type_id, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, &spit_publishing_authenticator_info);
		g_once_init_leave (&publishing_authenticator_shotwell_facebook_facebook_type_id__volatile, publishing_authenticator_shotwell_facebook_facebook_type_id);
	}
	return publishing_authenticator_shotwell_facebook_facebook_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



